Linux  R2.6.5-7.283-default FORTRAN90/SX         Rev.360        Wed Oct 22 11:35:45 2008
FILE NAME: i.lpj_constraints.f90
PROGRAM NAME: lpj_constraints
DIAGNOSTIC LIST

  LINE  LEVEL( NO.): DIAGNOSTIC MESSAGE

   109  vec  (   3): Unvectorized loop.
   109  vec  (  13): Overhead of loop division is too large.
   124  vec  (   4): Vectorized array expression.
   130  vec  (   4): Vectorized array expression.
   137  vec  (   4): Vectorized array expression.
   146  vec  (  18): Unvectorizable data type.
   148  vec  (   4): Vectorized array expression.
   162  vec  (   4): Vectorized array expression.
   168  vec  (   4): Vectorized array expression.
   175  vec  (   4): Vectorized array expression.
   182  vec  (   4): Vectorized array expression.
   192  vec  (   4): Vectorized array expression.
Linux  R2.6.5-7.283-default FORTRAN90/SX         Rev.360        Wed Oct 22 11:35:45 2008
FILE NAME: i.lpj_constraints.f90
PROGRAM NAME: lpj_constraints
FORMAT LIST

  LINE    LOOP     FORTRAN STATEMENT

     1:            ! determine whether a PFT is adapted and can regenerate
     2:            !
     3:            ! $Header: /home/ssipsl/CVSREP/ORCHIDEE/src_stomate/lpj_constraints.f90,v 1.7 2007/05/28 14:49:02 ssipsl Exp $
     4:            ! IPSL (2006)
     5:            !  This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
     6:            !
     7:            MODULE lpj_constraints
     8:            
     9:              ! modules used:
    10:            
    11:              USE ioipsl
    12:              USE stomate_constants
    13:            
    14:              IMPLICIT NONE
    15:            
    16:              ! private & public routines
    17:            
    18:              PRIVATE
    19:              PUBLIC constraints,constraints_clear
    20:            
    21:               ! first call
    22:                LOGICAL, SAVE                                    :: firstcall = .TRUE.
    23:            CONTAINS
    24:            
    25:            
    26:              SUBROUTINE constraints_clear
    27:                firstcall = .TRUE. 
    28:              END SUBROUTINE constraints_clear
    29:            
    30:              SUBROUTINE constraints (npts, dt, &
    31:                                      t2m_month, t2m_min_daily, when_growthinit, &
    32:                                      adapted, regenerate)
    33:            
    34:                !
    35:                ! 0 declarations
    36:                !
    37:            
    38:                ! 0.1 input
    39:            
    40:                ! Domain size
    41:                INTEGER(i_std), INTENT(in)                              :: npts
    42:                ! time step (in days)
    43:                REAL(r_std), INTENT(in)                           :: dt
    44:                ! "monthly" 2-meter temperature (K)
    45:                REAL(r_std), DIMENSION(npts), INTENT(in)          :: t2m_month
    46:                ! Daily minimum 2-meter temperature (K)
    47:                REAL(r_std), DIMENSION(npts), INTENT(in)          :: t2m_min_daily
    48:                ! how many days ago was the beginning of the growing season
    49:                REAL(r_std), DIMENSION(npts,npft), INTENT(in)     :: when_growthinit
    50:            
    51:                ! 0.2 output fields
    52:            
    53:                ! Winter too cold? between 0 and 1
    54:                REAL(r_std), DIMENSION(npts,npft), INTENT(inout)  :: adapted
    55:                ! Winter sufficiently cold? between 0 and 1
    56:                REAL(r_std), DIMENSION(npts,npft), INTENT(inout)  :: regenerate
    57:            
    58:                ! 0.3 local
    59:            
    60:                ! Memory length for adaption (d)
    61:                REAL(r_std)                                       :: tau_adapt
    62:                ! Memory length for regeneration (d)
    63:                REAL(r_std)                                       :: tau_regenerate 
    64:                ! longest sustainable time without regeneration (vernalization)
    65:                REAL(r_std), PARAMETER                            :: too_long = 5.
    66:                ! critical value of "regenerate" below which plant dies
    67:                REAL(r_std)                                       :: regenerate_min
    68:                ! index
    69:                INTEGER(i_std)                                    :: j
    70:            
    71:                ! =========================================================================
    72:            
    73:                IF (bavard.GE.3) WRITE(numout,*) 'Entering constraints'
    74:            
    75:                !
    76:                ! 1 Initializations
    77:                !
    78:                tau_adapt = one_year
    79:                tau_regenerate = one_year
    80:                !
    81:                ! 1.1 Messages
    82:                !
    83:            
    84:                IF ( firstcall ) THEN
    85:            
    86:                  WRITE(numout,*) 'constraints:'
    87:            
    88:                  WRITE(numout,*) '   > Memory length for adaption (d): ',tau_adapt
    89:                  WRITE(numout,*) '   > Memory length for regeneration (d): ',tau_regenerate
    90:                  WRITE(numout,*) '   > Longest sustainable time without vernalization (y):', too_long
    91:                  WRITE(numout,*) '   > For trees, longest sustainable time without growth init (y):', &
    92:                                        too_long
    93:            
    94:                  firstcall = .FALSE.
    95:            
    96:                ENDIF
    97:            
    98:                !
    99:                ! 1.2 critical value for "regenerate": below this value, the last vernalization
   100:                !     belong to a too distant past. PFT is then not adapted.
   101:                !
   102:            
   103:                regenerate_min = exp ( - too_long * one_year / tau_regenerate )
   104:            
   105:                !
   106:                ! 2 Loop over all PFTs
   107:                !
   108:            
   109: +------>       DO j = 1, npft
   110: |          
   111: |                IF ( natural(j) .OR. agriculture ) THEN
   112: |          
   113: |                  !
   114: |                  ! 2.1 climate criteria
   115: |                  !
   116: |          
   117: |                  ! 2.1.1 Test if PFT is adapted: check daily temperature.
   118: |                  !       If too cold, PFT is not adapted.
   119: |          
   120: |                  IF ( tmin_crit(j) .EQ. undef ) THEN
   121: |          
   122: |                    ! 2.1.1.1 some PFTs always survive.
   123: |          
   124: |V=====              adapted(:,j) = 1.
   125: |          
   126: |                  ELSE
   127: |          
   128: |                    ! 2.1.1.2 frost-sensitive PFTs
   129: |          
   130: |V----->             WHERE ( t2m_min_daily(:) .LT. tmin_crit(j) )
   131: |V-----                adapted(:,j) = 0.
   132: |                    ENDWHERE
   133: |          
   134: |                    ! limited memory: after some time, the cold shock is forgotten.
   135: |                    !  ( adapted will approach 1)
   136: |          
   137: |V=====              adapted(:,j) = 1. - ( 1. - adapted(:,j) ) * (tau_adapt- dt)/tau_adapt
   138: |          
   139: |                  ENDIF
   140: |          
   141: |                  !
   142: |                  ! 2.1.2 seasonal trees die if leafage does not show a clear seasonality.
   143: |                  !       (i.e. if the start of the growing season is never detected).
   144: |                  !
   145: |          
   146: |                  IF ( tree(j) .AND. ( pheno_crit%pheno_model(j) .NE. 'none' ) ) THEN
   147: |          
   148: |V----->             WHERE ( when_growthinit(:,j) .GT. too_long*one_year )
   149: |V-----                adapted(:,j) = 0.
   150: |                    ENDWHERE
   151: |          
   152: |                  ENDIF
   153: |          
   154: |                  ! 2.1.3 Test if PFT is regenerative
   155: |                  !       check monthly temperature. If sufficiently cold, PFT will be able to
   156: |                  !       regenerate for some time.
   157: |          
   158: |                  IF ( tcm_crit(j) .EQ. undef ) THEN
   159: |          
   160: |                    ! 2.1.3.1 several PFTs (ex: evergreen) don't need vernalization
   161: |          
   162: |V=====              regenerate(:,j) = 1.
   163: |          
   164: |                  ELSE
   165: |          
   166: |                    ! 2.1.3.2 PFT needs vernaliztion
   167: |          
   168: |V----->             WHERE ( t2m_month(:) .LE. tcm_crit(j) )
   169: |V-----                regenerate(:,j) = 1.
   170: |                    ENDWHERE
   171: |          
   172: |                    ! limited memory: after some time, the winter is forgotten.
   173: |                    !  (regenerate will approach 0)
   174: |          
   175: |V=====              regenerate(:,j) = regenerate(:,j) * (tau_regenerate-dt)/tau_regenerate
   176: |          
   177: |                  ENDIF
   178: |          
   179: |                  ! 2.1.4 Plants that need vernalization die after a few years if they don't
   180: |                  !       vernalize (even if they would not loose their leaves).
   181: |          
   182: |V----->           WHERE ( regenerate(:,j) .LE. regenerate_min )
   183: |V-----              adapted(:,j) = 0.
   184: |                  ENDWHERE
   185: |          
   186: |                ELSE
   187: |          
   188: |                  !
   189: |                  ! 2.2 PFT is not natural and agriculture is not allowed -> remove
   190: |                  !
   191: |          
   192: |V----->           adapted(:,j) = 0.
   193: ||         
   194: |V-----            regenerate(:,j) = 0.
   195: |          
   196: |                ENDIF
   197: |          
   198: +------        ENDDO
   199:            
   200:                IF (bavard.GE.4) WRITE(numout,*) 'Leaving constraints'
   201:            
   202:              END SUBROUTINE constraints
   203:            
   204:            END MODULE lpj_constraints
