Linux  R2.6.5-7.283-default FORTRAN90/SX         Rev.360        Wed Oct 22 11:35:45 2008
FILE NAME: i.lpj_cover.f90
PROGRAM NAME: lpj_cover
DIAGNOSTIC LIST

  LINE  LEVEL( NO.): DIAGNOSTIC MESSAGE

    68  vec  (   3): Unvectorized loop.
    68  vec  (  13): Overhead of loop division is too large.
    72  vec  (   4): Vectorized array expression.
    91  vec  (   3): Unvectorized loop.
    92  opt  (1592): Outer loop unrolled inside inner loop.
    92  vec  (   4): Vectorized array expression.
    95  warn (  83): Dummy argument "biomass" is not used.
Linux  R2.6.5-7.283-default FORTRAN90/SX         Rev.360        Wed Oct 22 11:35:45 2008
FILE NAME: i.lpj_cover.f90
PROGRAM NAME: lpj_cover
FORMAT LIST

  LINE    LOOP     FORTRAN STATEMENT

     1:            ! recalculate vegetation cover and LAI
     2:            !
     3:            ! $Header: /home/ssipsl/CVSREP/ORCHIDEE/src_stomate/lpj_cover.f90,v 1.7 2007/05/28 14:49:02 ssipsl Exp $
     4:            ! IPSL (2006)
     5:            !  This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
     6:            !
     7:            MODULE lpj_cover
     8:            
     9:              ! modules used:
    10:            
    11:              USE ioipsl
    12:              USE stomate_constants
    13:            
    14:              IMPLICIT NONE
    15:            
    16:              ! private & public routines
    17:            
    18:              PRIVATE
    19:              PUBLIC cover
    20:            
    21:            CONTAINS
    22:            
    23:              SUBROUTINE cover (npts, cn_ind, ind, biomass, &
    24:                                veget_max, veget, lai)
    25:            
    26:                !
    27:                ! 0 declarations
    28:                !
    29:            
    30:                ! 0.1 input
    31:            
    32:                ! Domain size
    33:                INTEGER(i_std), INTENT(in)                                   :: npts
    34:                ! crown area (m**2) per ind.
    35:                REAL(r_std), DIMENSION(npts,npft), INTENT(in)          :: cn_ind
    36:                ! density of individuals (1/(m**2 of nat/agri ground))
    37:                REAL(r_std), DIMENSION(npts,npft), INTENT(in)          :: ind
    38:                ! biomass (gC/(m**2 of nat/agri ground))
    39:                REAL(r_std), DIMENSION(npts,npft,nparts), INTENT(in)   :: biomass
    40:            
    41:                ! 0.2 modified fields
    42:            
    43:                ! "maximal" coverage fraction of a PFT (LAI -> infinity) on nat/agri ground
    44:                REAL(r_std), DIMENSION(npts,npft), INTENT(inout)       :: veget_max
    45:            
    46:                ! 0.3 output
    47:            
    48:                ! fractional coverage on natural/agricultural ground, taking into
    49:                !   account LAI (=grid-scale fpc)
    50:                REAL(r_std), DIMENSION(npts,npft), INTENT(inout)       :: veget
    51:                ! leaf area index OF AN INDIVIDUAL PLANT
    52:                REAL(r_std), DIMENSION(npts,npft), INTENT(in)         :: lai
    53:            
    54:                ! 0.4 local
    55:            
    56:                ! index
    57:                INTEGER(i_std)                                         :: j
    58:            
    59:                ! =========================================================================
    60:            
    61:                !
    62:                ! 1 If the vegetation is dynamic, calculate new maximum vegetation cover for
    63:                !   natural plants
    64:                !
    65:            
    66:                IF ( control%ok_dgvm ) THEN
    67:            
    68: +------>         DO j = 1, npft
    69: |          
    70: |                  IF ( natural(j) ) THEN
    71: |          
    72: |V=====              veget_max(:,j) = ind(:,j) * cn_ind(:,j)
    73: |          
    74: |                  ENDIF
    75: |          
    76: +------          ENDDO
    77:            
    78:                ENDIF
    79:            
    80:                !
    81:                ! 2 Calculate LAI
    82:                !   The LAI is defined on the space covered by the crown of the plant.
    83:                !    ( biomass / veget_max ) is in gC/(m**2 covered by the crown)
    84:                !
    85:            
    86:            
    87:                !
    88:                ! 3 calculate grid-scale fpc (foliage protected cover)
    89:                !
    90:            
    91: +------>       DO j = 1, npft
    92: |V=====          veget(:,j) = veget_max(:,j) * ( 1. - exp( - lai(:,j) * ext_coeff(j) ) )
    93: +------        ENDDO
    94:            
    95:              END SUBROUTINE cover
    96:            
    97:            END MODULE lpj_cover
